"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handlerProcedure = void 0;
const node_path_1 = __importDefault(require("node:path"));
const typescript_1 = __importDefault(require("typescript"));
const messages_constant_1 = require("../constants/messages.constant");
const error_util_1 = require("../utils/error.util");
const handlerProcedure = (options) => {
    return async () => {
        const parsedTsconfigPath = options.tsconfigPath === undefined ? undefined : node_path_1.default.parse(options.tsconfigPath);
        const configFile = typescript_1.default.findConfigFile(parsedTsconfigPath?.dir ?? ".", typescript_1.default.sys.fileExists, parsedTsconfigPath?.base);
        if (configFile === undefined)
            return {
                errors: [{
                        text: messages_constant_1.ErrorMessages.TSCONFIG_NOT_FOUND
                    }]
            };
        const config = typescript_1.default.readConfigFile(configFile, typescript_1.default.sys.readFile);
        const parsedConfig = typescript_1.default.parseJsonConfigFileContent(config.config, typescript_1.default.sys, node_path_1.default.dirname(configFile));
        const host = typescript_1.default.createCompilerHost(parsedConfig.options, true);
        const program = typescript_1.default.createProgram(parsedConfig.fileNames, parsedConfig.options, host);
        program.emit();
        const redundantDiagnostics = typescript_1.default.getPreEmitDiagnostics(program);
        const sourceDiagnostics = typescript_1.default.sortAndDeduplicateDiagnostics(redundantDiagnostics);
        const configDiagnostics = parsedConfig.errors;
        if (sourceDiagnostics.length === 0 && configDiagnostics.length === 0)
            return null;
        const partialSourceMessages = (0, error_util_1.mapDiagnosticsToPartialMessages)(host, Array.from(sourceDiagnostics));
        const partialConfigMessages = (0, error_util_1.mapDiagnosticsToPartialMessages)(host, configDiagnostics);
        return {
            errors: partialSourceMessages,
            warnings: partialConfigMessages
        };
    };
};
exports.handlerProcedure = handlerProcedure;
